import { NextApiRequest, NextApiResponse } from "next"
import getTokenFromBody from "../../lib/backend/components/getTokenFromBody"
import checkTokenIsValid from "../../lib/backend/components/checkTokenIsValid"
import getTokenDB from "../../lib/backend/components/getTokenDB"
import getPlayerByIdDB from "../../lib/backend/components/getPlayerByIdDB"
import sendResponse from "../../lib/backend/components/sendResponse"
import sendError from "../../lib/backend/components/sendError"
import { Logging } from "../../lib/backend/logging"
import { Game, Player, Token } from "@prisma/client"

interface Data {
  games: Game[]
}

export default async function data(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  return getTokenFromBody(req, res, (token) => {
    checkTokenIsValid(req, res, token, (tokenBody) => {
      getTokenDB(req, res, tokenBody, token[1], (tokenDB) => {
        getPlayerByIdDB(req, res, tokenDB, (player) => {
          sendResponse(req, res, dataResponse(player, tokenDB))
        })
      })
    })
  }).catch((err) => sendError(req, res, err))
}

function dataResponse<T>(player: Player, tokenDB: Token) {
  const games: any = {}
  // Successfull response
  return {
    message: `Requested data of user: ${player.id} with Access-Token: ${tokenDB.id}`,
    body: { games },
    type: ["debug", "info.cyan"] as Logging[],
  }
}
