import { NextApiRequest, NextApiResponse } from "next"
import checkTokenIsValid from "../../lib/backend/components/checkTokenIsValid"
import sendResponse from "../../lib/backend/components/sendResponse"
import sendError from "../../lib/backend/components/sendError"
import { deleteCookie } from "cookies-next"
import { Token } from "@prisma/client"
import getTokenDB from "../../lib/backend/components/getTokenDB"
import getTokenFromCookie from "../../lib/backend/components/getTokenFromCookie"
import { Logging } from "../../lib/backend/logging"

interface Data {
  loggedOut: boolean
}

export default async function logout(
  req: NextApiRequest,
  res: NextApiResponse<any>
) {
  return getTokenFromCookie(req, res, (token) => {
    checkTokenIsValid(req, res, token, (tokenBody) => {
      getTokenDB(req, res, tokenBody, token[1], (tokenDB) => {
        sendResponse(req, res, logoutResponse(tokenDB, req, res))
      })
    })
  }).catch((err) => sendError(req, res, err))
}

function logoutResponse<T>(
  tokenDB: Token,
  req: NextApiRequest,
  res: NextApiResponse<T>
) {
  // Set login cookie
  deleteCookie("token", { req, res })

  // Successfull response
  return {
    message: "User of Token " + tokenDB.id + " logged out.",
    body: { loggedOut: true },
    type: ["debug", "info.cyan"] as Logging[],
  }
}
